billingMethod property
Specifies the billing method for a test run: metered or
unmetered. If the parameter is not specified, the default value
is metered.
Implementation
final BillingMethod? billingMethod;
Specifies the billing method for a test run: metered or
unmetered. If the parameter is not specified, the default value
is metered.
final BillingMethod? billingMethod;